@@ -5,7 +5,7 @@ package Alt::Data::Frame::ButMore;
 use strict;
 use warnings;
 
-our $VERSION = '0.0042_03'; # TRIAL VERSION
+our $VERSION = '0.0044_01'; # TRIAL VERSION
 
 1;
 
@@ -21,7 +21,7 @@ Alt::Data::Frame::ButMore - Alternative implementation of Data::Frame with more
 
 =head1 VERSION
 
-version 0.0042_03
+version 0.0044_01
 
 =head1 STATUS
 
@@ -80,6 +80,13 @@ So here I release my L<Alt> implenmentation.
 This implements a data frame container that uses L<PDL> for individual columns.
 As such, it supports marking missing values (C<BAD> values).
 
+=head2 Document Conventions
+
+Function signatures in docs of this library follow the
+L<Function::Parameters> conventions, for example,
+
+    function(Type1 $positional_parameter, Type2 :$named_parameter)
+
 =head1 CONSTRUCTION
 
     new( (ArrayRef | HashRef) :$columns,
@@ -312,11 +319,11 @@ Parameters:
 
 =item *
 
-C<$percentiles>
+$percentiles
 
 The percentiles to include in the output. All should fall between 0 and 1.
-The default is [.25, .75], which returns the 25th, 50th, and 75th
-percentiles (0.5 would be automatically included).
+The default is C<[.25, .75]>, which returns the 25th, 50th, and 75th
+percentiles (median is always automatically included).
 
 =back
 
@@ -573,15 +580,15 @@ This method is internally used by the C<.=> operation, below are same,
 
 =head1 MISCELLANEOUS FEATURES
 
-=head2 SERIALIZATION
+=head2 Serialization
 
 See L<Data::Frame::IO::CSV>
 
-=head2 SYNTAX SUGAR
+=head2 Syntax Sugar
 
 See L<Data::Frame::Partial::Sugar>
 
-=head2 TIDY EVALUATION
+=head2 Tidy Evaluation
 
 This feature is somewhat similar to R's tidy evaluation.
 
