@@ -53,24 +53,6 @@ catch {
       . '';
 }
 
-#TODO: switch from csv to some other format for speed
-fun _make_data ( $name, $setup ) {
-    return sub {
-        state $df;
-        unless ( defined $df ) {
-            $df = Data::Frame->from_csv(
-                "$data_raw_dir/$name.csv",
-                header => true,
-                %{ $setup->{params} }
-            );
-            if (my $postprocess = $setup->{postprocess}) {
-                $df = $postprocess->($df);
-            }
-        }
-        return $df;
-    };
-}
-
 for my $name (@data_names) {
     no strict 'refs';
     *{$name} = _make_data( $name, $data_setup{$name} );
@@ -96,6 +78,26 @@ sub _factorize {
     return $df;
 };
 
+#TODO: switch from csv to some other format for speed
+sub _make_data {
+    my ( $name, $setup ) = @_;
+
+    return sub {
+        state $df;
+        unless ( defined $df ) {
+            $df = Data::Frame->from_csv(
+                "$data_raw_dir/$name.csv",
+                header => true,
+                %{ $setup->{params} }
+            );
+            if (my $postprocess = $setup->{postprocess}) {
+                $df = $postprocess->($df);
+            }
+        }
+        return $df;
+    };
+}
+
 1;
 
 __END__
@@ -110,7 +112,7 @@ Data::Frame::Examples - Example data sets
 
 =head1 VERSION
 
-version 0.0042_03
+version 0.0044_01
 
 =head1 SYNOPSIS
 
