@@ -2,8 +2,7 @@ package Data::Frame::PDL;
 
 # ABSTRACT: A mixin to add some methods to PDL
 
-use 5.010;
-use strict;
+use 5.016;
 use warnings;
 
 use Role::Tiny;
@@ -13,10 +12,6 @@ use PDL::Core qw(pdl);
 use PDL::Primitive qw(which);
 use POSIX qw(ceil);
 use Safe::Isa;
-use Types::Standard qw(Int);
-use Type::Params;
-
-my $PositiveInt = Int->where( sub { $_ > 0 } );
 
 
 sub length { $_[0]->dim(0); }
@@ -158,37 +153,51 @@ Data::Frame::PDL - A mixin to add some methods to PDL
 
 =head1 VERSION
 
-version 0.0042_03
+version 0.0044_01
 
 =head1 DESCRIPTION
 
 This module provides a role that can add a few methods to the PDL class.
 
-It's an internal module used by Data::Frame. Do not use it in your code!
+It's an internal module used by the Data::Frame library to add a few methods
+to the PDL class. Do not directly use this module in your code, as the
+module name may change in future.
 
 =head1 METHODS
 
-=head2 length()
+=head2 length
+
+    length()
 
 Returns the length of the first dimension.
 
-=head2 diff($lag=1)
+=head2 diff
 
-=head2 flatten()
+    length($lag=1)
+
+=head2 flatten
+
+    flatten()
 
 This is same as C<@{$self-E<gt>unpdl}>.
 
-=head2 flatten_deep()
+=head2 flatten_deep
+
+    flatten_deep()
 
 This is same as C<list()>.
 
-=head2 repeat($n)
+=head2 repeat
+
+    repeat($n)
 
 Repeat on the first dimension for C<$n> times.
 
 Only works with 1D piddle.  
 
-=head2 repeat_to_length($length)
+=head2 repeat_to_length
+
+    repeat_to_length($length)
 
 Repeat to have the given length.
 
@@ -196,6 +205,8 @@ Only works with 1D piddle.
 
 =head2 id
 
+    id()
+
 Compute a unique numeric id for each element in a piddle.
 
 =head1 SEE ALSO
